@@ -12,14 +12,15 @@ import os
 import copy
 import collections
 import datetime
+import sys
 
 import nbformat
 
 from traitlets.config.configurable import LoggingConfigurable
 from traitlets.config import Config
-from traitlets import HasTraits, Unicode, List, TraitError
+from traitlets import Bool, HasTraits, Unicode, List, TraitError
 from traitlets.utils.importstring import import_item
-from ipython_genutils import text, py3compat
+from typing import Optional
 
 
 class ResourcesDict(collections.defaultdict):
@@ -35,7 +36,7 @@ class FilenameExtension(Unicode):
 
     def validate(self, obj, value):
         # cast to proper unicode
-        value = super(FilenameExtension, self).validate(obj, value)
+        value = super().validate(obj, value)
 
         # check that it starts with a dot
         if value and not value.startswith('.'):
@@ -52,7 +53,11 @@ class Exporter(LoggingConfigurable):
     accompanying resources dict.
     """
 
-    file_extension = FilenameExtension('.txt',
+    enabled = Bool(True,
+        help = "Disable this exporter (and any exporters inherited from it)."
+    ).tag(config=True)
+
+    file_extension = FilenameExtension(
         help="Extension of the file that should be written to disk"
     ).tag(config=True)
 
@@ -79,7 +84,6 @@ class Exporter(LoggingConfigurable):
                                   'nbconvert.preprocessors.ExecutePreprocessor',
                                   'nbconvert.preprocessors.coalesce_streams',
                                   'nbconvert.preprocessors.SVG2PDFPreprocessor',
-                                  'nbconvert.preprocessors.CSSHTMLHeaderPreprocessor',
                                   'nbconvert.preprocessors.LatexPreprocessor',
                                   'nbconvert.preprocessors.HighlightMagicsPreprocessor',
                                   'nbconvert.preprocessors.ExtractOutputPreprocessor',
@@ -95,7 +99,7 @@ class Exporter(LoggingConfigurable):
 
         Parameters
         ----------
-        config : :class:`~traitlets.config.Config`
+        config : ``traitlets.config.Config``
             User configuration instance.
         `**kw`
             Additional keyword arguments passed to parent __init__
@@ -105,7 +109,7 @@ class Exporter(LoggingConfigurable):
         if config:
             with_default_config.merge(config)
 
-        super(Exporter, self).__init__(config=with_default_config, **kw)
+        super().__init__(config=with_default_config, **kw)
 
         self._init_preprocessors()
 
@@ -120,13 +124,13 @@ class Exporter(LoggingConfigurable):
 
         Parameters
         ----------
-        nb : :class:`~nbformat.NotebookNode`
-          Notebook node (dict-like with attr-access)
+        nb : `nbformat.NotebookNode`
+            Notebook node (dict-like with attr-access)
         resources : dict
-          Additional resources that can be accessed read/write by
-          preprocessors and filters.
+            Additional resources that can be accessed read/write by
+            preprocessors and filters.
         `**kw`
-          Ignored
+            Ignored
 
         """
         nb_copy = copy.deepcopy(nb)
@@ -140,8 +144,7 @@ class Exporter(LoggingConfigurable):
 
         return nb_copy, resources
 
-
-    def from_filename(self, filename, resources=None, **kw):
+    def from_filename(self, filename: str, resources: Optional[dict] = None, **kw):
         """
         Convert a notebook from a notebook file.
 
@@ -150,30 +153,29 @@ class Exporter(LoggingConfigurable):
         filename : str
             Full filename of the notebook file to open and convert.
         resources : dict
-          Additional resources that can be accessed read/write by
-          preprocessors and filters.
+            Additional resources that can be accessed read/write by
+            preprocessors and filters.
         `**kw`
-          Ignored
+            Ignored
 
         """
-        # Convert full filename string to unicode
-        # In python 2.7.x if filename comes as unicode string,
-        # just skip converting it.
-        if isinstance(filename, str):
-           filename = py3compat.str_to_unicode(filename)
-
         # Pull the metadata from the filesystem.
         if resources is None:
             resources = ResourcesDict()
         if not 'metadata' in resources or resources['metadata'] == '':
             resources['metadata'] = ResourcesDict()
         path, basename = os.path.split(filename)
-        notebook_name = basename[:basename.rfind('.')]
+        notebook_name = os.path.splitext(basename)[0]
         resources['metadata']['name'] = notebook_name
         resources['metadata']['path'] = path
 
         modified_date = datetime.datetime.fromtimestamp(os.path.getmtime(filename))
-        resources['metadata']['modified_date'] = modified_date.strftime(text.date_format)
+        # datetime.strftime date format for ipython
+        if sys.platform == 'win32':
+            date_format = "%B %d, %Y"
+        else:
+            date_format = "%B %-d, %Y"
+        resources['metadata']['modified_date'] = modified_date.strftime(date_format)
 
         with io.open(filename, encoding='utf-8') as f:
             return self.from_file(f, resources=resources, **kw)
@@ -188,10 +190,10 @@ class Exporter(LoggingConfigurable):
         file_stream : file-like object
             Notebook file-like object to convert.
         resources : dict
-          Additional resources that can be accessed read/write by
-          preprocessors and filters.
+            Additional resources that can be accessed read/write by
+            preprocessors and filters.
         `**kw`
-          Ignored
+            Ignored
 
         """
         return self.from_notebook_node(nbformat.read(file_stream, as_version=4), resources=resources, **kw)
@@ -201,13 +203,13 @@ class Exporter(LoggingConfigurable):
         """
         Register a preprocessor.
         Preprocessors are classes that act upon the notebook before it is
-        passed into the Jinja templating engine.  preprocessors are also
+        passed into the Jinja templating engine. Preprocessors are also
         capable of passing additional information to the Jinja
         templating engine.
 
         Parameters
         ----------
-        preprocessor : :class:`~nbconvert.preprocessors.Preprocessor`
+        preprocessor : `nbconvert.preprocessors.Preprocessor`
             A dotted module name, a type, or an instance
         enabled : bool
             Mark the preprocessor as enabled
@@ -219,7 +221,7 @@ class Exporter(LoggingConfigurable):
         constructed = not isclass
 
         # Handle preprocessor's registration based on it's type
-        if constructed and isinstance(preprocessor, py3compat.string_types):
+        if constructed and isinstance(preprocessor, str,):
             # Preprocessor is a string, import the namespace and recursively call
             # this register_preprocessor method
             preprocessor_cls = import_item(preprocessor)
@@ -255,7 +257,7 @@ class Exporter(LoggingConfigurable):
         """
         self._preprocessors = []
 
-        # Load default preprocessors (not necessarly enabled by default).
+        # Load default preprocessors (not necessarily enabled by default).
         for preprocessor in self.default_preprocessors:
             self.register_preprocessor(preprocessor)
 
@@ -310,14 +312,14 @@ class Exporter(LoggingConfigurable):
         nbc =  copy.deepcopy(nb)
         resc = copy.deepcopy(resources)
 
-        #Run each preprocessor on the notebook.  Carry the output along
-        #to each preprocessor
+        # Run each preprocessor on the notebook.  Carry the output along
+        # to each preprocessor
         for preprocessor in self._preprocessors:
             nbc, resc = preprocessor(nbc, resc)
-            try: 
+            try:
                 nbformat.validate(nbc, relax_add_props=True)
             except nbformat.ValidationError:
-                self.log.error('Notebook is invalid after preprocessor {}',
+                self.log.error('Notebook is invalid after preprocessor %s',
                                preprocessor)
                 raise
 
